==> nextcloud-app-mail-1.13.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Belangrik",
    "Work" : "Werk",
    "Personal" : "Persoonlik",
    "Mail" : "Pos",
    "Name" : "Naam",
    "Mail address" : "Posadres",
    "Password" : "Wagwoord",
    "Manual" : "Handmatig",
    "IMAP Host" : "IMAP-gasheer",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Signature" : "Handtekening",
    "Cancel" : "Kanselleer",
    "Add mail account" : "Voeg posrekening toe",
    "Subject" : "Onderwerp",
    "Sending …" : "Stuur…",
    "Go back" : "Gaan terug",
    "Retry" : "Herprobeer",
    "Message sent!" : "Boodskap gestuur!",
    "Send" : "Stuur",
    "Favorite" : "Gunsteling",
    "Select" : "Kies",
    "Move" : "Skuif",
    "All day" : "Heeldag",
    "Create" : "Skep",
    "Choose" : "Kies",
    "Favorites" : "Gunstelinge",
    "Other" : "Ander",
    "Reply" : "Antwoord",
    "Forward" : "Stuur aan",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Unnamed" : "Naamloos",
    "New message" : "Nuwe boodskap",
    "Settings" : "Instellings",
    "Quota" : "Kwota",
    "Saving" : "Stoor tans",
    "Remove account" : "Verwyder rekening",
    "Loading …" : "Laai …",
    "Delete" : "Skrap",
    "Add" : "Voeg by",
    "Custom" : "Eie",
    "Set" : "Stel in",
    "Remove" : "Verwyder",
    "Reset" : "Herstel",
    "General" : "Algemeen",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Keyboard shortcut" : "Snelsleutel",
    "Keyboard shortcuts" : "Sneltoetse",
    "Search" : "Soek",
    "Refresh" : "Verfris",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Archive" : "Argief",
    "Drafts" : "Konsepte",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Indien u nie daardie blad wil besoek nie, kan u na <a href=\"%s\">Pos</a> terugkeer."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-2.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/af.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Belangrik",
    "Work" : "Werk",
    "Personal" : "Persoonlik",
    "Mail" : "Pos",
    "Name" : "Naam",
    "Mail address" : "Posadres",
    "Password" : "Wagwoord",
    "Manual" : "Handmatig",
    "IMAP Host" : "IMAP-gasheer",
    "None" : "Geen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-poort",
    "IMAP User" : "IMAP-gebruiker",
    "IMAP Password" : "IMAP-wagwoord",
    "SMTP Host" : "SMTP-gasheer",
    "SMTP Port" : "SMTP-poort",
    "SMTP User" : "SMTP-gebruiker",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Connect" : "Verbind",
    "Signature" : "Handtekening",
    "Cancel" : "Kanselleer",
    "Add mail account" : "Voeg posrekening toe",
    "Subject" : "Onderwerp",
    "Sending …" : "Stuur…",
    "Go back" : "Gaan terug",
    "Retry" : "Herprobeer",
    "Message sent!" : "Boodskap gestuur!",
    "Send" : "Stuur",
    "Favorite" : "Gunsteling",
    "Select" : "Kies",
    "Move" : "Skuif",
    "Forward" : "Stuur aan",
    "All day" : "Heeldag",
    "Create" : "Skep",
    "Comment" : "Kommentaar",
    "Accept" : "Aanvaar",
    "Choose" : "Kies",
    "Other" : "Ander",
    "Reply" : "Antwoord",
    "Import into calendar" : "Voer in na kalender",
    "Download attachment" : "Laai aanhangsel af",
    "Unnamed" : "Naamloos",
    "Quota" : "Kwota",
    "Saving" : "Stoor tans",
    "Remove account" : "Verwyder rekening",
    "Loading …" : "Laai …",
    "New message" : "Nuwe boodskap",
    "Delete" : "Skrap",
    "Add" : "Voeg by",
    "Search" : "Soek",
    "Custom" : "Eie",
    "Set" : "Stel in",
    "Remove" : "Verwyder",
    "Reset" : "Herstel",
    "General" : "Algemeen",
    "User" : "Gebruiker",
    "Host" : "Gasheer",
    "Port" : "Poort",
    "Keyboard shortcut" : "Snelsleutel",
    "Keyboard shortcuts" : "Sneltoetse",
    "Refresh" : "Verfris",
    "Connect your mail account" : "Koppel u posrekening",
    "All" : "Alle",
    "Archive" : "Argief",
    "Drafts" : "Konsepte",
    "Favorites" : "Gunstelinge",
    "All inboxes" : "Alle inkassies",
    "Inbox" : "Inkassie",
    "Junk" : "Gemorspos",
    "Sent" : "Gestuur",
    "Trash" : "Asblik",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Forwarding to %s" : "Stuur aan na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
    "Redirect" : "Herverwys",
    "The link leads to %s" : "Die skakel lei na %s"
},
"nplurals=2; plural=(n != 1);");
